Index: gcl.py |
diff --git a/gcl.py b/gcl.py |
index 775ab94dd6ce9d346749bfa987c3a00be6b99b83..0332a2b83dded77bdad30b4929841c3d9c0ae33c 100755 |
--- a/gcl.py |
+++ b/gcl.py |
@@ -403,9 +403,9 @@ class ChangeInfo(object): |
if self.issue and self.patchset: |
try: |
self.SendToRietveld('/lint/issue%s_%s' % (self.issue, self.patchset), |
- timeout=10) |
+ timeout=60) |
except ssl.SSLError as e: |
# It takes more than 10 seconds to lint some CLs. Silently ignore |
# the expected timeout. |
if e.message != 'The read operation timed out': |
raise |
@@ -403,9 +403,9 @@ class ChangeInfo(object): |
except ssl.SSLError as e: |
- # It takes more than 10 seconds to lint some CLs. Silently ignore |
+ # It takes more than 60 seconds to lint some CLs. Silently ignore |
# the expected timeout. |
if e.message != 'The read operation timed out': |